@@ -19,14 +19,13 @@
 #ifndef CATEGORYLIST_H
 #define CATEGORYLIST_H
 
-#include <KHBox>
+#include <QWidget>
 
 class QModelIndex;
 class QAbstractItemModel;
 
-class KUrl;
 
-class CategoryList : public KHBox
+class CategoryList : public QWidget
 {
     Q_OBJECT
 
@@ -34,10 +33,10 @@ public:
     explicit CategoryList( QWidget *parent, QAbstractItemModel *model );
     virtual ~CategoryList();
 
-    void changeModule( QModelIndex newItem);
+    void changeModule( const QModelIndex &newItem);
 
 Q_SIGNALS:
-    void moduleSelected( QModelIndex itemSelected );
+    void moduleSelected( const QModelIndex &itemSelected );
 
 private Q_SLOTS:
     void slotModuleLinkClicked( const QUrl& moduleName );
